@@ -4,6 +4,7 @@ import openpyxl
 import sys
 import os
 import shutil
+import psutil
 from openpyxl.utils import column_index_from_string
 from datetime import datetime
 
@@ -98,26 +99,14 @@ def CountOccurenceOfValueInString(string,sub_string):
             count+=1
     return count     
 
-def DisposeWebDriver():
-        """
-        Closes the browser and shuts down the ChromeDriver executable
-        that is started when starting the ChromeDriver
-        """			
-        try:
-            self._debug('Closing all browsers')        
-            browser.quit(self)
-            browser.dispose(self)
-            self._cache.close_all()
-            self.empty_cache()
-            RemoteWebDriver.close(self)
-            Thread.Sleep(4000)
-            RemoteWebDriver.quit(self)
-            RemoteWebDriver.dispose(self)
-            RemoteWebDrive = null
-            WindowsUtils.KillProcessAndChildren("C:\Program Files\Python38\Scripts\chromedriver.exe") 
-        except:
-            # something probably has gone wrong
-            pass
+def  KillProcess(process_name):
+     """
+      Kill the inputted process_name
+     """
+     for proc in psutil.process_iter():
+        # check whether the process_name matches a running process
+        if proc.name() == process_name:
+            proc.kill()
             
 def RemoveSpecialCharacters(str):
      """
